/*******************************************************************************
 *
 * Copyright(c) 2011 Analog Devices, Inc. All Rights Reserved.
 *
 * This software is proprietary and confidential.  By using this software you
 * agree to the terms of the associated Analog Devices License Agreement.
 *
 ******************************************************************************/

/*!
* @file      adi_ether_misra.h
*
* @brief     Define Misra rule which are suppressed
*
*/

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

/* MISRA RULES Enabled */
#ifdef _MISRA_RULES
    
/* Rule 2.1(Req) : Assembly language shall be encapsulated and isolated */
#pragma diag (suppress: misra_rule_2_1: "Use of inline Assembly is required")
/* Rule 5.3(Req) : A typedef shall be a unique identifier */
#pragma diag (suppress: misra_rule_5_3)
/* Rule 5.4(Req) : A tag name shall be a unique identifier */
#pragma diag (suppress: misra_rule_5_4)
/* Rule 8.7(Req): Objects shall be defined at block scope if they are only accessed from within a single function */
#pragma diag (suppress: misra_rule_8_7: "Source access the driver internal structure once and a pointer to that used there after")
/* Rule 14.7(Req): A function shall have a single point of exit at the end of the function.*/
#pragma diag (suppress: misra_rule_14_7: "Allowing several point of exit increases code readabilty and maintainability")
/* Rule 17.4(Req): Array indexing shall be the only allowed form of pointer arithmetic. */
#pragma diag (suppress: misra_rule_17_4: "This source needs to use pointer indexing")
/* Rule 20.6(Req): The macro offsetof, in library <stddef.h>, shall not be used */
#pragma diag (suppress: misra_rule_20_6: "This source require the use of offset")
/* Rule 5.1: Macro names is greater than 31 characters */
#pragma diag(suppress:misra_rule_5_1:"macro name is more than 31 characters")
/* Rule 5.6 (Adv): No identifier in one namespace should have the same spelling */
#pragma diag(suppress:misra_rule_5_6:"No identifer in one name space should have the same spelling")
/* Rule 5.7 (Adv): No identifier name should be reused with enums */
#pragma diag(suppress:misra_rule_5_7:"No identifer name should be reused ")
/* Rule 19.1 (Adv):#include statements in a file should only preceded by other preprocessor directives or comments */
#pragma diag(suppress:misra_rule_19_1:"#include statements in a file should only preceded by other preprocessor directives or comments")
#endif /* _MISRA_RULES */

#ifdef __cplusplus
}
#endif

