/*
****************************************************************************
Copyright (c), 2010-2013 - Analog Devices Inc. All Rights Reserved.
This software is proprietary & confidential to Analog Devices, Inc.
and its licensors.
******************************************************************************
$Revision: 30641 $
$Date: 2015-04-14 10:20:03 -0400 (Tue, 14 Apr 2015) $
Title: ADI MISRA C 2004 compliance matrix and suppression directives for ADuCxxx

Description:

    IAR Suppression Matrix:
    Error[Pm002]: compiler is configured to allow extensions - all code shall conform 
                  to ISO 9899 standard C, with no extensions permitted (MISRA C 2004 rule 1.1)
    Error[Pm064]: functions with variable number of arguments shall not be used (MISRA C 2004 rule 16.1)
    Error[Pm073]: a function should have a single point of exit (MISRA C 2004 rule 14.7)
    Error[Pm081]: #undef should not be used (MISRA C 2004 rule 19.6)
    Error[Pm086]: there shall be at most one occurrence of the # or ## preprocessor operator
                  in a single macro definition (MISRA C 2004 rule 19.12)
    Error[Pm093]: use of union - overlapping storage shall not be used (MISRA C 2004 rule 18.4)
    Error[Pm143]: a function should have a single point of exit at the end of the function 
                  (MISRA C 2004 rule 14.7)
    Error[Pm152]: array indexing shall only be applied to objects defined as an array type
                  (MISRA C 2004 rule 17.4)
    
    IAR Suppression Matrix:
    Error[Pm073]:  a function should have a single point of exit 
                   (MISRA C 2004 rule 14.7) 
    
    Error[Pm088]: pointer arithmetic should not be used (MISRA C 2004 rule 17.4) 
    
    Error[Pm100]: dynamic heap memory allocation shall not be used 
                  (MISRA C 2004 rule 20.4)   
    
    Error[Pm114]: an 'if (expression)' construct shall be followed by a compound 
                  statement. The 'else' keyword shall be followed by either a 
                  compound statement, or another 'if'  statement 
                  (MISRA C 2004 rule 14.9)
    
    Error[Pm120]: the # and ## preprocessor operators should not be used 
                  (MISRA C 2004 rule 19.13)
    
    Error[Pm123]: there shall be no definition of objects or functions in a 
                  header file (MISRA C 2004 rule 8.5)
    
    Error[Pm127]: a 'U' suffix shall be applied to all constants of 'unsigned' type 
                  (MISRA C 2004 rule 10.6)
    
    Error[Pm128]: illegal implicit conversion from underlying MISRA type 
                  (MISRA C 2004 rule 10.1) 
    
    Error[Pm138]: conversions shall not be performed between a pointer to a 
                  function and any other type other than an integral type 
                  (MISRA C 2004 rule 11.1)
    
    Error[Pm139]: conversions shall not be performed between a pointer to object 
                  and any type other than an integral type     
                  (MISRA C 2004 rule 11.2)
    
    Error[Pm140]: a cast should not be performed between a pointer type and an 
                  integral type (MISRA C 2004 rule 11.3)
    
    Error[Pm141]: a cast should not be performed between a pointer to object type
                  and a different pointer to object type(MISRA C 2004 rule 11.4)
    
    Error[Pm143]: a function should have a single point of exit at the end of 
                  the function (MISRA C 2004 rule 14.7)                 
    
*****************************************************************************/
/*! @file osal_misra.h */
 /*! @cond */
#ifndef __ADI_OSAL_MISRA_H__
#define __ADI_OSAL_MISRA_H__


#if defined ( __ICCARM__ )  /* IAR compiler... */

/* assert */
/*#define  ASSERT_ADI_OSAL_MISRA_SUPPRESSIONS  _Pragma ("diag_suppress= Pm001,Pm002,Pm073,Pm088,Pm100,Pm114,Pm120,Pm123,Pm127,Pm128,Pm138,Pm139,Pm140,Pm141,Pm143")*/
/*deassert */
/*#define  REVERT_ADI_OSAL_MISRA_SUPPRESSIONS  _Pragma ("diag_default=  Pm001,Pm002,Pm073,Pm088,Pm100,Pm114,Pm120,Pm123,Pm127,Pm128,Pm138,Pm139,Pm140,Pm141,Pm143")*/
/*assert */

#define  ADI_OSAL_MISRA_SUPPRESS_ALL _Pragma ("diag_suppress=                \
     Pm001,Pm002,Pm003,Pm004,Pm005,Pm006,Pm007,Pm008,Pm009,Pm010,Pm011, \
     Pm012,Pm013,Pm014,Pm015,Pm016,Pm017,Pm018,Pm019,Pm020,Pm021,Pm022, \
     Pm023,Pm024,Pm025,Pm026,Pm027,Pm028,Pm029,Pm030,Pm031,Pm032,Pm033, \
     Pm034,Pm035,Pm036,Pm037,Pm038,Pm039,Pm040,Pm041,Pm042,Pm043,Pm044, \
     Pm045,Pm046,Pm047,Pm048,Pm049,Pm050,Pm051,Pm052,Pm053,Pm054,Pm055, \
     Pm056,Pm057,Pm058,Pm059,Pm060,Pm061,Pm062,Pm063,Pm064,Pm065,Pm066, \
     Pm067,Pm068,Pm069,Pm070,Pm071,Pm072,Pm073,Pm074,Pm075,Pm076,Pm077, \
     Pm078,Pm079,Pm080,Pm081,Pm082,Pm083,Pm084,Pm085,Pm086,Pm087,Pm088, \
     Pm089,Pm090,Pm091,Pm092,Pm093,Pm094,Pm095,Pm096,Pm097,Pm098,Pm099, \
     Pm100,Pm101,Pm102,Pm103,Pm104,Pm105,Pm106,Pm107,Pm108,Pm109,Pm110, \
     Pm111,Pm112,Pm113,Pm114,Pm115,Pm116,Pm117,Pm118,Pm119,Pm120,Pm121, \
     Pm122,Pm123,Pm124,Pm125,Pm126,Pm127,Pm128,Pm129,Pm130,Pm131,Pm132, \
     Pm133,Pm134,Pm135,Pm136,Pm137,Pm138,Pm139,Pm140,Pm141,Pm142,Pm143, \
     Pm144,Pm145,Pm146,Pm147,Pm148,Pm149,Pm150,Pm151,Pm152,Pm153,Pm154, \
     Pm155") 

#define  ADI_OSAL_MISRA_RESTORE_ALL _Pragma ("diag_default=                  \
     Pm001,Pm002,Pm003,Pm004,Pm005,Pm006,Pm007,Pm008,Pm009,Pm010,Pm011, \
     Pm012,Pm013,Pm014,Pm015,Pm016,Pm017,Pm018,Pm019,Pm020,Pm021,Pm022, \
     Pm023,Pm024,Pm025,Pm026,Pm027,Pm028,Pm029,Pm030,Pm031,Pm032,Pm033, \
     Pm034,Pm035,Pm036,Pm037,Pm038,Pm039,Pm040,Pm041,Pm042,Pm043,Pm044, \
     Pm045,Pm046,Pm047,Pm048,Pm049,Pm050,Pm051,Pm052,Pm053,Pm054,Pm055, \
     Pm056,Pm057,Pm058,Pm059,Pm060,Pm061,Pm062,Pm063,Pm064,Pm065,Pm066, \
     Pm067,Pm068,Pm069,Pm070,Pm071,Pm072,Pm073,Pm074,Pm075,Pm076,Pm077, \
     Pm078,Pm079,Pm080,Pm081,Pm082,Pm083,Pm084,Pm085,Pm086,Pm087,Pm088, \
     Pm089,Pm090,Pm091,Pm092,Pm093,Pm094,Pm095,Pm096,Pm097,Pm098,Pm099, \
     Pm100,Pm101,Pm102,Pm103,Pm104,Pm105,Pm106,Pm107,Pm108,Pm109,Pm110, \
     Pm111,Pm112,Pm113,Pm114,Pm115,Pm116,Pm117,Pm118,Pm119,Pm120,Pm121, \
     Pm122,Pm123,Pm124,Pm125,Pm126,Pm127,Pm128,Pm129,Pm130,Pm131,Pm132, \
     Pm133,Pm134,Pm135,Pm136,Pm137,Pm138,Pm139,Pm140,Pm141,Pm142,Pm143, \
     Pm144,Pm145,Pm146,Pm147,Pm148,Pm149,Pm150,Pm151,Pm152,Pm153,Pm154, \
     Pm155") 

#else
/* assert */
#define  ASSERT_OSAL_ADI_MISRA_SUPPRESSIONS 

/* deassert */
#define  REVERT_OSAL_ADI_MISRA_SUPPRESSIONS 

#define  ADI_OSAL_MISRA_SUPPRESS_ALL

#define  ADI_OSAL_MISRA_RESTORE_ALL

#endif

#endif /* __ADI_OSAL_MISRA_H__ */
/*! @endcond */