/*********************************************************************************

Copyright(c) 2015 Analog Devices, Inc. All Rights Reserved.

This software is proprietary and confidential.  By using this software you agree
to the terms of the associated Analog Devices License Agreement.

*********************************************************************************/

/*!
 * @file:    adi_cpt_def_v1.h
 * @brief:   Capture Timer service definitions
 * @version: $Revision: 31408 $
 * @date:    $Date: 2015-06-11 14:00:16 -0400 (Thu, 11 Jun 2015) $
 *
 * @details
 *            This file contains Capture Timer static function and structure
 *            definitions used in the APIs
 */

#ifndef _ADI_CPT_DEF_V1_H_
#define _ADI_CPT_DEF_V1_H_

/* 
 * temp definitions until Coda generated file is available 
 */
   
#define TRGS_CPT0_TRIG_A                    63           
#define TRGS_CPT0_TRIG_B                    64           
#define TRGS_CPT1_TRIG_A                    65           
#define TRGS_CPT1_TRIG_B                    66           
#define TRGS_CPT2_TRIG_A                    67           
#define TRGS_CPT2_TRIG_B                    68           

/* 
 * end temp definitions until Coda generated file is available 
 */

/* Capture Timer instance data. */
typedef struct _ADI_CPT_DATA
{
    ADI_CALLBACK        pfCallback;       /* Application supplied callback. */
    void               *pCBParam;         /* Application supplied callback parameter. */
} ADI_CPT_DATA;

/* Common CPTMR registers */
typedef struct _ADI_CPT_COMMON_REGS_
{
    volatile uint32_t  CPT_RUN;
    volatile uint32_t  CPT_RUNST;
    volatile uint32_t  CPT_RUNCL;
    volatile uint32_t  CPT_DATA_IMASK;
    volatile uint32_t  CPT_DATA_IMASKST;
    volatile uint32_t  CPT_DATA_IMASKCL;
    volatile uint32_t  CPT_STATUS_IMASK;
    volatile uint32_t  CPT_STATUS_IMASKST;
    volatile uint32_t  CPT_STATUS_IMASKCL;
    volatile uint32_t  CPT_DATA_ILAT;
    volatile uint32_t  CPT_STATUS_ILAT;
} ADI_CPT_COMMON_REGS;

/* CPTMR registers */
typedef struct _ADI_CPT_REGS_
{
    volatile uint32_t  CPT_CONFIG;
    volatile uint32_t  CPT_COUNTER;
    volatile uint32_t  CPT_TON;
} ADI_CPT_REGS;

/* Structure which holds mostly static information */
typedef struct _ADI_CPTMR_DEVICE_
{   
    const uint32_t                           nTimerID;                /* Capture Timer number */
    volatile ADI_CPT_REGS          *const    pCPTRegs;                /* Pointer to CPTMR registers */
    const uint32_t                           nStatusIntID;            /* Status interrupt ID */
    const uint32_t                           nDataIntID;              /* Measurement interrupt ID */
    ADI_CPT_DATA                            *pDevData;                /* Pointer to timer instance data. */
} ADI_CPT_DEVICE;

/* Number of ADCC Devices in the processor */
#define ADI_CPT_NUM_DEVICES            (sizeof(gCPTDevices)/sizeof(ADI_CPT_DEVICE))

/*=============== Local functions =======================*/

/* Status interrupt handler */
static void StatusIntHandler(
    uint32_t            IID,
    void               *pCBParam
);

/* Data interrupt handler */
static void DataIntHandler(
    uint32_t            IID,
    void               *pCBParam
);

#ifdef ADI_DEBUG
/* Validates the device handle */
static ADI_CPT_RESULT ValidateDeviceHandle (
    ADI_CPT_DEVICE     *const pDevice
);
#endif

#endif /* _ADI_CPT_DEF_V1_H_ */
