/*********************************************************************************

Copyright(c) 2013-2014 Analog Devices, Inc. All Rights Reserved.

This software is proprietary and confidential.  By using this software you agree
to the terms of the associated Analog Devices License Agreement.

*********************************************************************************/

/*!
 * @file:    adi_tru_def.h
 * @brief:   Private header file for ADSP-BF60x/ADSP-BF70x/ADSP-CM40z/ADSP-SC58x processor TRU Manager.
 * @version: $Revision: 26490 $
 * @date:    $Date: 2014-07-24 17:13:02 -0400 (Thu, 24 Jul 2014) $
 *
 * @details
 *           This is a private header file for the TRU Manager service
 *           for ADSP-BF60x/ADSP-CM40z processor family, which contains the API declarations,
 *           data and constant definitions used in TRU Manager implementation
 */

#ifndef __ADI_TRU_DEF_H__
#define __ADI_TRU_DEF_H__

/*=============  I N C L U D E S   =============*/

/* OSAL includes */
#include <adi_osal.h>
/* TRU Manager includes */
#include <services/tru/adi_tru.h>
/* memcpy includes */
#include <string.h>
/* Memory size check */
#include <assert.h>
/* device includes */
#include <sys/platform.h>


/*==============  D E F I N E S  ===============*/

#pragma pack(4)
/* Structure to handle remaining TRU registers */
typedef struct
{
    volatile uint32_t   MasterTrigger;      /* TRU Master Trigger Register */
    volatile uint32_t   Padding1;           /* Padding to handle Register gap */
    volatile uint32_t   ErrorAddress;       /* TRU Error Address Register */
    volatile uint32_t   Status;             /* TRU Status Information Register */
/* IF (ADSP-BF60x/70x/58x) */
#if defined( __ADSPBF609_FAMILY__) || defined (__ADSPBF707_FAMILY__) || defined (__ADSPSC589_FAMILY__)
    volatile uint32_t   RevID;              /* TRU Revision ID Register */
/* ELSE (ADSP-CM40z Processor family) */
#else
    volatile uint32_t   Padding2;           /* Padding to handle Register gap */
#endif
    volatile uint32_t   GlobalControl;      /* TRU Global Control Register */
} ADI_TRU_REGS;
#pragma pack()

#pragma pack(4)
/* Structure to handle a TRU device instance */
typedef struct
{
	uint8_t				DeviceNumber;   /* TRU device number */
} ADI_TRU_DEV;
#pragma pack()

/* Structure to hold TRU specific information */
typedef struct
{
    ADI_TRU_DEV                 *pDevice;       /* Pointer to device instance memory */
    volatile uint32_t 			*pSSReg;   		/* Pointer to First TRU Slave Select Register */
    volatile ADI_TRU_REGS 	    *pReg;          /* Pointer to the remaining TRU Registers */
} ADI_TRU_INFO;

#endif  /* __ADI_TRU_DEF_H__ */

/*****/
